@@ -1,3 +1,4 @@
+# $Id: ConfigReader.pm 380 2005-03-10 02:59:51Z claco $
 package Handel::ConfigReader;
 use strict;
 use warnings;
@@ -69,10 +70,6 @@ Handel::ConfigReader - Read in Handel configuration settings
     my $cfg = Handel::ConfigReader-new();
     my $setting = $cfg->get('HandelMaxQuantity');
 
-=head1 VERSION
-
-    $Id: ConfigReader.pm 285 2005-03-04 02:29:22Z claco $
-
 =head1 DESCRIPTION
 
 Handel::ConfigReader is a generic wrapper to get various configuration
@@ -154,5 +151,5 @@ options using C<|>.
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
